@@ -142,8 +142,8 @@ static void set_winner(void)
 		strcat(winner, get_msg(M_WINS));
 	}
 	
-	clear_text(20/* max len, probably */, 20 + 50, YS - 50);
-	draw_message(winner, 20 + 50, YS - 50, FALSE);
+	clear_text(20/* max len, probably */, G_MSG_X, G_MSG_Y);
+	draw_message(winner, G_MSG_X, G_MSG_Y, FALSE);
 
 	free(winner);
 	SDL_Delay(1500);	
